pm4py.algo.filtering.log.variants package
=========================================

Submodules
----------

pm4py.algo.filtering.log.variants.variants\_filter module
---------------------------------------------------------

.. automodule:: pm4py.algo.filtering.log.variants.variants_filter
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.filtering.log.variants
   :members:
   :undoc-members:
   :show-inheritance:
